@@ -1,5 +1,5 @@
 package Devel::PatchPerl;
-$Devel::PatchPerl::VERSION = '1.26';
+$Devel::PatchPerl::VERSION = '1.30';
 # ABSTRACT: Patch perl source a la Devel::PPPort's buildperl.pl
 
 use strict;
@@ -127,6 +127,7 @@ my @patch = (
               [ \&_patch_conf_solaris ],
               [ \&_patch_bitrig ],
               [ \&_patch_hints ],
+              [ \&_patch_patchlevel ],
             ],
   },
   {
@@ -369,6 +370,29 @@ sub _determine_version {
   return $version;
 }
 
+# adapted from patchlevel.h for use with perls that predate it
+sub _patch_patchlevel {
+  my $dpv = $Devel::PatchPerl::VERSION || "(unreleased)";
+  open my $plin, "patchlevel.h" or die "Couldn't open patchlevel.h : $!";
+  open my $plout, ">patchlevel.new" or die "Couldn't write on patchlevel.new : $!";
+  my $seen=0;
+  while (<$plin>) {
+      if (/\t,NULL/ and $seen) {
+        print {$plout} qq{\t,"Devel::PatchPerl $dpv"\n};
+      }
+      $seen++ if /local_patches\[\]/;
+      print {$plout} $_;
+  }
+  close $plout or die "Couldn't close filehandle writing to patchlevel.new : $!";
+  close $plin or die "Couldn't close filehandle reading from patchlevel.h : $!";
+  unlink "patchlevel.bak" or warn "Couldn't unlink patchlevel.bak : $!"
+    if -e "patchlevel.bak";
+  rename "patchlevel.h", "patchlevel.bak" or
+    die "Couldn't rename patchlevel.h to patchlevel.bak : $!";
+  rename "patchlevel.new", "patchlevel.h" or
+    die "Couldn't rename patchlevel.new to patchlevel.h : $!";
+}
+
 sub _patch_hints {
   my @os;
   push @os, $^O;
@@ -2593,8 +2617,8 @@ sub _patch_5183_metajson {
 _patch(<<'DOGSAY');
 diff --git a/META.json b/META.json
 index 64caea7..200e324 100644
---- a/META.json
-+++ b/META.json
+--- META.json
++++ META.json
 @@ -118,7 +118,7 @@
           "TestInit.pm"
        ]
@@ -2628,7 +2652,7 @@ Devel::PatchPerl - Patch perl source a la Devel::PPPort's buildperl.pl
 
 =head1 VERSION
 
-version 1.26
+version 1.30
 
 =head1 SYNOPSIS
 
